@@ -29,13 +29,13 @@ class Player(pygame.sprite.Sprite):
         pygame.sprite.Sprite.__init__(self)
         self.images = []
 
-        self.images.append(pygame.image.load('snake1.png'))
-        self.images.append(pygame.image.load('Snake_start.png'))
-        self.images.append(pygame.image.load('Snake_Firemid.png'))
-        self.images.append(pygame.image.load('snake2.png'))
-        self.images.append(pygame.image.load('Snake_fire_end.png'))
-        self.images.append(pygame.image.load('snake4.png'))
-        self.images.append(pygame.image.load('snake6.png'))
+        self.images.append(pygame.image.load('PythonPals/snake1.png'))
+        self.images.append(pygame.image.load('PythonPals/Snake_start.png'))
+        self.images.append(pygame.image.load('PythonPals/Snake_Firemid.png'))
+        self.images.append(pygame.image.load('PythonPals/snake2.png'))
+        self.images.append(pygame.image.load('PythonPals/Snake_fire_end.png'))
+        self.images.append(pygame.image.load('PythonPals/snake4.png'))
+        self.images.append(pygame.image.load('PythonPals/snake6.png'))
 
         self.index = 0
         self.image = self.images[self.index]
@@ -61,12 +61,12 @@ class Coffee(pygame.sprite.Sprite):
     def __init__(self):
         pygame.sprite.Sprite.__init__(self)
         self.images = []
-        self.images.append(pygame.image.load('coffee1.png'))
-        self.images.append(pygame.image.load('coffee2.png'))
-        self.images.append(pygame.image.load('coffee3.png'))
-        self.images.append(pygame.image.load('coffee4.png'))
-        self.images.append(pygame.image.load('coffee5.png'))
-        self.images.append(pygame.image.load('coffee6.png'))
+        self.images.append(pygame.image.load('PythonPals/coffee1.png'))
+        self.images.append(pygame.image.load('PythonPals/coffee2.png'))
+        self.images.append(pygame.image.load('PythonPals/coffee3.png'))
+        self.images.append(pygame.image.load('PythonPals/coffee4.png'))
+        self.images.append(pygame.image.load('PythonPals/coffee5.png'))
+        self.images.append(pygame.image.load('PythonPals/coffee6.png'))
 
         self.index = 0
         self.image = self.images[self.index]
@@ -92,15 +92,15 @@ class Ruby(pygame.sprite.Sprite):
     def __init__(self):
         pygame.sprite.Sprite.__init__(self)
         self.images = []
-        self.images.append(pygame.image.load('Ruby_idle.png'))
-        self.images.append(pygame.image.load('Ruby_left.png'))
-        self.images.append(pygame.image.load('Ruby_prep.png'))
-        self.images.append(pygame.image.load('Ruby_start.png'))
-        self.images.append(pygame.image.load('Ruby_fire.png'))
-        self.images.append(pygame.image.load('Ruby_start.png'))
-        self.images.append(pygame.image.load('Ruby_prep.png'))
-        self.images.append(pygame.image.load('Ruby_left.png'))
-        self.images.append(pygame.image.load('Ruby_hurt.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_idle.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_left.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_prep.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_start.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_fire.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_start.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_prep.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_left.png'))
+        self.images.append(pygame.image.load('PythonPals/Ruby_hurt.png'))
 
         self.index = 0
         self.image = self.images[self.index]
@@ -126,10 +126,10 @@ class Eye(pygame.sprite.Sprite):
     def __init__(self):
         pygame.sprite.Sprite.__init__(self)
         self.images = []
-        self.images.append(pygame.image.load('C1.png'))
-        self.images.append(pygame.image.load('C2.png'))
-        self.images.append(pygame.image.load('C3.png'))
-        self.images.append(pygame.image.load('C4.png'))
+        self.images.append(pygame.image.load('PythonPals/C1.png'))
+        self.images.append(pygame.image.load('PythonPals/C2.png'))
+        self.images.append(pygame.image.load('PythonPals/C3.png'))
+        self.images.append(pygame.image.load('PythonPals/C4.png'))
 
 
         self.index = 0
@@ -261,7 +261,7 @@ class button():
         pygame.draw.rect(screen, self.color, (round(self.x), round(self.y), round(self.width), round(self.height)), 0)
 
         if self.text != '':
-            font = pygame.font.Font('JandaManateeSolid.ttf', fontSize)
+            font = pygame.font.Font('PythonPals/JandaManateeSolid.ttf', fontSize)
             text = font.render(self.text, 1, text_color)
             if center:
                 screen.blit(text, (round(self.x + (self.width / 2 - text.get_width() / 2)),
@@ -300,7 +300,7 @@ class text():
 
         if len(self.text) != 0:
             size = len(self.text)
-            font = pygame.font.Font("JandaManateeSolid.ttf", fontSize)
+            font = pygame.font.Font("PythonPals/JandaManateeSolid.ttf", fontSize)
             i = 0
             if center:
                 for part in self.text:
@@ -657,23 +657,23 @@ def drawBackground(playerGroup, enemyGroup, width, height, level, correctOrWrong
     # screen.fill(white)
     #pygame.draw.rect(screen, (0, 0, 0), (0, 0, theScreen.width, theScreen.height * 0.07))
     if level == 1:
-        bg = pygame.image.load("jungleBackground.jpg")
+        bg = pygame.image.load("PythonPals/jungleBackground.jpg")
         bg = pygame.transform.rotozoom(bg, 0, theScreen.width / 1380)
     elif level == 2:
-        bg = pygame.image.load("goldmine.jpg")
+        bg = pygame.image.load("PythonPals/goldmine.jpg")
         bg = pygame.transform.rotozoom(bg, 0, theScreen.width / 1400)
     else:
-        bg = pygame.image.load("ocean.jpg")
+        bg = pygame.image.load("PythonPals/ocean.jpg")
         bg = pygame.transform.rotozoom(bg, 0, theScreen.width / 1900)
     screen.blit(bg,(0,0))
     if correctOrWrong != "":
         if correctOrWrong == "Correct":
-            pygame.mixer.Sound("correct.wav").play()
+            pygame.mixer.Sound("PythonPals/correct.wav").play()
             display = text(black, theScreen.width * 0.25, theScreen.height * 0.2, theScreen.width * 0.5,
                                   theScreen.height * 0.4, int(theScreen.width * 0.02), ["Correct"])
             pygame.draw.rect(screen, (0,255,0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
         if correctOrWrong == "Wrong":
-            pygame.mixer.Sound("incorrect.wav").play()
+            pygame.mixer.Sound("PythonPals/incorrect.wav").play()
             display = text(black, theScreen.width * 0.25, theScreen.height * 0.2, theScreen.width * 0.5,
                                   theScreen.height * 0.4, int(theScreen.width * 0.02), ["Incorrect"])
             pygame.draw.rect(screen, (255, 0, 0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
@@ -855,7 +855,7 @@ def theBattle(level):
         ans_button_color = color_light
 
         myEnemy = Coffee()
-        pygame.mixer.music.load('jazz.mp3')
+        pygame.mixer.music.load('PythonPals/jazz.mp3')
         pygame.mixer.music.play(-1)
     elif level == 2:
         cat_button_color = (240,208,79)
@@ -863,7 +863,7 @@ def theBattle(level):
         ans_button_color = color_dark
 
         myEnemy = Ruby()
-        pygame.mixer.music.load('funke.mp3')
+        pygame.mixer.music.load('PythonPals/funke.mp3')
         pygame.mixer.music.play(-1)
     else:
         cat_button_color = color_dark
@@ -871,7 +871,7 @@ def theBattle(level):
         ans_button_color = color_dark
 
         myEnemy = Eye()
-        pygame.mixer.music.load('bluth.wav')
+        pygame.mixer.music.load('PythonPals/bluth.wav')
         pygame.mixer.music.play(-1)
 
     enemyGroup = pygame.sprite.Group(myEnemy)
@@ -955,12 +955,12 @@ def theBattle(level):
             return "win"
 
 def win():
-    pygame.mixer.music.load('victoire.mp3')
+    pygame.mixer.music.load('PythonPals/victoire.mp3')
     pygame.mixer.music.play(-1)
 
     print("You won!")
     screen.fill((100, 100, 100))
-    snake = pygame.image.load("snake6.png")
+    snake = pygame.image.load("PythonPals/snake6.png")
     snake.convert()
     # snake = pygame.transform.rotozoom(snake, 0, 0.7)
     screen.blit(snake, (theScreen.width * 0.43, theScreen.height * 0.6))
@@ -973,12 +973,12 @@ def win():
     pygame.time.delay(4000)
 
 def lose():
-    pygame.mixer.music.load('defaite.mp3')
+    pygame.mixer.music.load('PythonPals/defaite.mp3')
     pygame.mixer.music.play(-1)
 
     print("You lost!")
     screen.fill((100, 100, 100))
-    snake = pygame.image.load("snake5.png")
+    snake = pygame.image.load("PythonPals/snake5.png")
     snake.convert()
     #snake = pygame.transform.rotozoom(snake, 0, 0.7)
     screen.blit(snake, (theScreen.width * 0.4, theScreen.height * 0.6))
@@ -1054,15 +1054,15 @@ def q_deck_menu():
                     options()
                     opt = False
                 if changeCapitals.isOver(pos):
-                    globals()['ws'] = changeQuestionDeck("python_questions_capitals.xlsx", ws)
+                    globals()['ws'] = changeQuestionDeck("PythonPals/python_questions_capitals.xlsx", ws)
                     options()
                     opt = False
                 if changePython.isOver(pos):
-                    globals()['ws'] = changeQuestionDeck("python_questions.xlsx", ws)
+                    globals()['ws'] = changeQuestionDeck("PythonPals/python_questions.xlsx", ws)
                     options()
                     opt = False
                 if changeHistory.isOver(pos):
-                    globals()['ws'] = changeQuestionDeck("python_questions_timeline.xlsx", ws)
+                    globals()['ws'] = changeQuestionDeck("PythonPals/python_questions_timeline.xlsx", ws)
                     options()
                     opt = False
             if ev.type == pygame.VIDEORESIZE:
@@ -1150,15 +1150,15 @@ def main():
         #  go to start, options, or quit
         if menuOption == "start":
             damageStats.modify(50,10)
-            levelChange(screen, 1, "Java", "coffee1.png")
+            levelChange(screen, 1, "Java", "PythonPals/coffee1.png")
             result = theBattle(1)
             restart_music = True
             if result == "win":
-                levelChange(screen, 2, "Ruby", "Ruby_idle.png")
+                levelChange(screen, 2, "Ruby", "PythonPals/Ruby_idle.png")
                 damageStats.modify(25,25)
                 result2 = theBattle(2)
                 if result2 == "win":
-                    levelChange(screen, 3, "Eye", "C1.png")
+                    levelChange(screen, 3, "Eye", "PythonPals/C1.png")
                     damageStats.modify(17,25)
                     result3 = theBattle(3)
                     if result3 == "win":
